==> zzyj-laborservice-impl-3.0.0-20241213.060323-56-sources.jar: com/ejianc/business/itax/bean/SalaryDetailEntity.java <==
package com.ejianc.business.itax.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工人工资上传明细
 * 
 * @author generator
 * 
 */
 @TableName("zzyj_laborservice_itax_salary_detail")
public class SalaryDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 劳务队长人姓名
    @TableField(value="org_id")
    private Long orgId; // 单位id
    @TableField(value="org_name")
    private String orgName; // 单位名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="project_name")
    private String projectName; // 项目
    @TableField(value="id_num")
    private String idNum; // 身份证号
    @TableField(value="name")
    private String name; // 姓名
    @TableField(value="phone")
    private String phone; // 联系电话
    @TableField(value="money")
    private BigDecimal money; // 本次发放金额
    @TableField(value="effective_start_time")
    private Date effectiveStartTime; // 有效开始日期
    @TableField(value="pid")
    private Long pid; // 父id
    @TableField(value="month_num")
    private Integer monthNum; // 计算个税入职月份
    @TableField(value="is_regist")
    private String isRegist; // 是否在系统登记
    @TableField(value="last_month_state")
    private String lastMonthState; // 上月申报状态
    @TableField(value="this_month_num")
    private Integer thisMonthNum; // 本月代发次数
    @TableField(value="this_year_income")
    private BigDecimal thisYearIncome; // 截至本单已申报本年度累计收入
    @TableField(value="this_month_dlffje")
    private BigDecimal thisMonthDlffje; // 本月累计办理代发金额
    @TableField(value="this_month_income_itax")
    private BigDecimal thisMonthIncomeItax; // 本月应纳税所得额
    @TableField(value="expense_reduction")
    private BigDecimal expenseReduction; // 累计减除费用
    @TableField(value="this_year_itax")
    private BigDecimal thisYearItax; // 截至本月已申报个税
    @TableField(value="this_month_prepay_itax")
    private BigDecimal thisMonthPrepayItax; // 本月预缴个税
    @TableField(value="special_deduction")
    private BigDecimal specialDeduction; // 专项附加扣除
    @TableField(value="last_month_wsb_itax")
    private BigDecimal lastMonthWsbItax; // 上月未申报个税
    @TableField(value="last_month_wsb_income")
    private BigDecimal lastMonthWsbIncome; // 上月未申报收入金额
    @TableField(value="this_month_itax")
    private BigDecimal thisMonthItax; // 计算个税
    @TableField(value="this_month_itax_yj")
    private BigDecimal thisMonthItaxYj; // 已交个税
    @TableField(value="salary_pay_state")
    private String salaryPayState; // 工资发放状态
    @TableField(value="user_state")
    private Integer userState; // 人员状态(1已在系统中登记2未在系统中登记)


    public Integer getUserState() {
        return userState;
    }

    public void setUserState(Integer userState) {
        this.userState = userState;
    }

    public String getSalaryPayState() {
        return salaryPayState;
    }

    public void setSalaryPayState(String salaryPayState) {
        this.salaryPayState = salaryPayState;
    }

    public Integer getMonthNum() {
        return monthNum;
    }

    public void setMonthNum(Integer monthNum) {
        this.monthNum = monthNum;
    }

    public String getIsRegist() {
        return isRegist;
    }

    public void setIsRegist(String isRegist) {
        this.isRegist = isRegist;
    }

    public String getLastMonthState() {
        return lastMonthState;
    }

    public void setLastMonthState(String lastMonthState) {
        this.lastMonthState = lastMonthState;
    }

    public Integer getThisMonthNum() {
        return thisMonthNum;
    }

    public void setThisMonthNum(Integer thisMonthNum) {
        this.thisMonthNum = thisMonthNum;
    }

    public BigDecimal getThisYearIncome() {
        return thisYearIncome;
    }

    public void setThisYearIncome(BigDecimal thisYearIncome) {
        this.thisYearIncome = thisYearIncome;
    }

    public BigDecimal getThisMonthDlffje() {
        return thisMonthDlffje;
    }

    public void setThisMonthDlffje(BigDecimal thisMonthDlffje) {
        this.thisMonthDlffje = thisMonthDlffje;
    }

    public BigDecimal getThisMonthIncomeItax() {
        return thisMonthIncomeItax;
    }

    public void setThisMonthIncomeItax(BigDecimal thisMonthIncomeItax) {
        this.thisMonthIncomeItax = thisMonthIncomeItax;
    }

    public BigDecimal getExpenseReduction() {
        return expenseReduction;
    }

    public void setExpenseReduction(BigDecimal expenseReduction) {
        this.expenseReduction = expenseReduction;
    }

    public BigDecimal getThisYearItax() {
        return thisYearItax;
    }

    public void setThisYearItax(BigDecimal thisYearItax) {
        this.thisYearItax = thisYearItax;
    }

    public BigDecimal getThisMonthPrepayItax() {
        return thisMonthPrepayItax;
    }

    public void setThisMonthPrepayItax(BigDecimal thisMonthPrepayItax) {
        this.thisMonthPrepayItax = thisMonthPrepayItax;
    }

    public BigDecimal getSpecialDeduction() {
        return specialDeduction;
    }

    public void setSpecialDeduction(BigDecimal specialDeduction) {
        this.specialDeduction = specialDeduction;
    }

    public BigDecimal getLastMonthWsbItax() {
        return lastMonthWsbItax;
    }

    public void setLastMonthWsbItax(BigDecimal lastMonthWsbItax) {
        this.lastMonthWsbItax = lastMonthWsbItax;
    }

    public BigDecimal getLastMonthWsbIncome() {
        return lastMonthWsbIncome;
    }

    public void setLastMonthWsbIncome(BigDecimal lastMonthWsbIncome) {
        this.lastMonthWsbIncome = lastMonthWsbIncome;
    }

    public BigDecimal getThisMonthItax() {
        return thisMonthItax;
    }

    public void setThisMonthItax(BigDecimal thisMonthItax) {
        this.thisMonthItax = thisMonthItax;
    }

    public BigDecimal getThisMonthItaxYj() {
        return thisMonthItaxYj;
    }

    public void setThisMonthItaxYj(BigDecimal thisMonthItaxYj) {
        this.thisMonthItaxYj = thisMonthItaxYj;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getIdNum() {
        return idNum;
    }

    public void setIdNum(String idNum) {
        this.idNum = idNum;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }
    public Date getEffectiveStartTime() {
        return effectiveStartTime;
    }

    public void setEffectiveStartTime(Date effectiveStartTime) {
        this.effectiveStartTime = effectiveStartTime;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    
}

==> zzyj-laborservice-impl-3.0.0-20250218.021957-73-sources.jar: com/ejianc/business/itax/bean/SalaryDetailEntity.java <==
package com.ejianc.business.itax.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 工人工资上传明细
 * 
 * @author generator
 * 
 */
 @TableName("zzyj_laborservice_itax_salary_detail")
public class SalaryDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 劳务队长人姓名
    @TableField(value="org_id")
    private Long orgId; // 单位id
    @TableField(value="org_name")
    private String orgName; // 单位名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_code")
    private String projectCode; // 项目code
    @TableField(value="project_name")
    private String projectName; // 项目
    @TableField(value="id_num")
    private String idNum; // 身份证号
    @TableField(value="name")
    private String name; // 姓名
    @TableField(value="phone")
    private String phone; // 联系电话
    @TableField(value="money")
    private BigDecimal money; // 本次发放金额
    @TableField(value="effective_start_time")
    private Date effectiveStartTime; // 有效开始日期
    @TableField(value="pid")
    private Long pid; // 父id
    @TableField(value="month_num")
    private Integer monthNum; // 计算个税入职月份
    @TableField(value="is_regist")
    private String isRegist; // 是否在系统登记
    @TableField(value="last_month_state")
    private String lastMonthState; // 上月申报状态
    @TableField(value="this_month_num")
    private Integer thisMonthNum; // 本月代发次数
    @TableField(value="this_year_income")
    private BigDecimal thisYearIncome; // 截至本单已申报本年度累计收入
    @TableField(value="this_month_dlffje")
    private BigDecimal thisMonthDlffje; // 本月累计办理代发金额
    @TableField(value="this_month_income_itax")
    private BigDecimal thisMonthIncomeItax; // 本月应纳税所得额
    @TableField(value="expense_reduction")
    private BigDecimal expenseReduction; // 累计减除费用
    @TableField(value="this_year_itax")
    private BigDecimal thisYearItax; // 截至本月已申报个税
    @TableField(value="this_month_prepay_itax")
    private BigDecimal thisMonthPrepayItax; // 本月预缴个税
    @TableField(value="special_deduction")
    private BigDecimal specialDeduction; // 专项附加扣除
    @TableField(value="last_month_wsb_itax")
    private BigDecimal lastMonthWsbItax; // 上月未申报个税
    @TableField(value="last_month_wsb_income")
    private BigDecimal lastMonthWsbIncome; // 上月未申报收入金额
    @TableField(value="this_month_itax")
    private BigDecimal thisMonthItax; // 计算个税
    @TableField(value="this_month_itax_yj")
    private BigDecimal thisMonthItaxYj; // 已交个税
    @TableField(value="salary_pay_state")
    private String salaryPayState; // 工资发放状态
    @TableField(value="user_state")
    private Integer userState; // 人员状态(1已在系统中登记2未在系统中登记)
    @TableField(value="itax_state")
    private String itaxState; // 个税收取状态


    public String getItaxState() {
        return itaxState;
    }

    public void setItaxState(String itaxState) {
        this.itaxState = itaxState;
    }

    public Integer getUserState() {
        return userState;
    }

    public void setUserState(Integer userState) {
        this.userState = userState;
    }

    public String getSalaryPayState() {
        return salaryPayState;
    }

    public void setSalaryPayState(String salaryPayState) {
        this.salaryPayState = salaryPayState;
    }

    public Integer getMonthNum() {
        return monthNum;
    }

    public void setMonthNum(Integer monthNum) {
        this.monthNum = monthNum;
    }

    public String getIsRegist() {
        return isRegist;
    }

    public void setIsRegist(String isRegist) {
        this.isRegist = isRegist;
    }

    public String getLastMonthState() {
        return lastMonthState;
    }

    public void setLastMonthState(String lastMonthState) {
        this.lastMonthState = lastMonthState;
    }

    public Integer getThisMonthNum() {
        return thisMonthNum;
    }

    public void setThisMonthNum(Integer thisMonthNum) {
        this.thisMonthNum = thisMonthNum;
    }

    public BigDecimal getThisYearIncome() {
        return thisYearIncome;
    }

    public void setThisYearIncome(BigDecimal thisYearIncome) {
        this.thisYearIncome = thisYearIncome;
    }

    public BigDecimal getThisMonthDlffje() {
        return thisMonthDlffje;
    }

    public void setThisMonthDlffje(BigDecimal thisMonthDlffje) {
        this.thisMonthDlffje = thisMonthDlffje;
    }

    public BigDecimal getThisMonthIncomeItax() {
        return thisMonthIncomeItax;
    }

    public void setThisMonthIncomeItax(BigDecimal thisMonthIncomeItax) {
        this.thisMonthIncomeItax = thisMonthIncomeItax;
    }

    public BigDecimal getExpenseReduction() {
        return expenseReduction;
    }

    public void setExpenseReduction(BigDecimal expenseReduction) {
        this.expenseReduction = expenseReduction;
    }

    public BigDecimal getThisYearItax() {
        return thisYearItax;
    }

    public void setThisYearItax(BigDecimal thisYearItax) {
        this.thisYearItax = thisYearItax;
    }

    public BigDecimal getThisMonthPrepayItax() {
        return thisMonthPrepayItax;
    }

    public void setThisMonthPrepayItax(BigDecimal thisMonthPrepayItax) {
        this.thisMonthPrepayItax = thisMonthPrepayItax;
    }

    public BigDecimal getSpecialDeduction() {
        return specialDeduction;
    }

    public void setSpecialDeduction(BigDecimal specialDeduction) {
        this.specialDeduction = specialDeduction;
    }

    public BigDecimal getLastMonthWsbItax() {
        return lastMonthWsbItax;
    }

    public void setLastMonthWsbItax(BigDecimal lastMonthWsbItax) {
        this.lastMonthWsbItax = lastMonthWsbItax;
    }

    public BigDecimal getLastMonthWsbIncome() {
        return lastMonthWsbIncome;
    }

    public void setLastMonthWsbIncome(BigDecimal lastMonthWsbIncome) {
        this.lastMonthWsbIncome = lastMonthWsbIncome;
    }

    public BigDecimal getThisMonthItax() {
        return thisMonthItax;
    }

    public void setThisMonthItax(BigDecimal thisMonthItax) {
        this.thisMonthItax = thisMonthItax;
    }

    public BigDecimal getThisMonthItaxYj() {
        return thisMonthItaxYj;
    }

    public void setThisMonthItaxYj(BigDecimal thisMonthItaxYj) {
        this.thisMonthItaxYj = thisMonthItaxYj;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getIdNum() {
        return idNum;
    }

    public void setIdNum(String idNum) {
        this.idNum = idNum;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }
    public Date getEffectiveStartTime() {
        return effectiveStartTime;
    }

    public void setEffectiveStartTime(Date effectiveStartTime) {
        this.effectiveStartTime = effectiveStartTime;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    
}
